function  Root=iterat2_2(Fun,p0,TOL,N)
%%     function Root=iterat2_2(Fun,p0,TOL);
%%     Fixed-point Iteration procedure is to find the approximate root
%%     of Fun.
%%        
%%
%%  INPUT:
%%    Fun - the function which must be entered as a string,
%%          enclosed in ' ', with the name the m-file of the  function
%%    TOL - tolerance that integral is to be computed to on each level
%%    p0 - the initial approximation
%%    N - the maximum iteration number
%%  OUTPUT:
%%    Root  - approximate Root or
%%     message that limit on levels is exceeded
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Root=feval(Fun,p0);
i=1;
while abs(Root-p0)>TOL
      p0=Root;
      Root=feval(Fun,p0);
      if i>N
	 massage='This method failed'
	 break;
      end;
end;
